@@ -30,7 +30,7 @@ class PrometheusSpeedtestTest(unittest.TestCase):
         self.assertEqual(tester.test(), expected)
 
         mock_speedtest.assert_called_once_with(source_address='4.3.2.1',
-                                               timeout=10)
+                                               timeout=10, secure=True)
         mock_speedtest.return_value.get_best_server.assert_called_once_with()
         mock_speedtest.return_value.download.assert_called_once_with()
         mock_speedtest.return_value.upload.assert_called_once_with()
